@@ -147,7 +147,7 @@ class Repository(abc.ABC):
         Args:
             models: Entity class or classes to obtain.
         """
-        entities = self._all(models)
+        entities = sorted(self._all(models))
 
         # ignore: the type cannot be List[Entity] but it can, I don't know how to fix
         # this
@@ -190,7 +190,7 @@ class Repository(abc.ABC):
         Raises:
             EntityNotFoundError: If the entities are not found.
         """
-        found_entities = self._search(fields, models)
+        found_entities = sorted(self._search(fields, models))
 
         # ignore: the type cannot be List[Entity] but it can, I don't know how to fix
         # this
@@ -310,3 +310,8 @@ class Repository(abc.ABC):
         elif not isinstance(models, list):
             models = [models]
         return models
+
+    @abc.abstractmethod
+    def close(self) -> None:
+        """Close the connection to the database."""
+        raise NotImplementedError
